@@ -57,7 +57,7 @@ class GrimoirePage:
         Return all urls into a array
         """
         try:
-            return self.data["server"].keys()
+            return self.data['server'].keys()
         except:
             return []
 
@@ -79,14 +79,12 @@ class GrimoirePage:
         for url in url_to_run:
             for command in command_to_run:
                 cl = map_command[command]()
-                self.data["server"][url][command] = cl.execute(
-                    directive=command, data=self.data["server"][url]
-                )
+                self.data['server'][url][command] = cl.execute(directive=command, data=self.data['server'][url])
 
-        with open(self.setting_manager.data_path, "w") as json_file:
+        with open(self.setting_manager.data_path, 'w') as json_file:
             json.dump(self.data, json_file)
 
-    def stats(self, command=None, url=None) -> None:
+    def stats(self, command=None, url=None) -> bool:
         """
         Launch stats command for plugin
         """
@@ -95,6 +93,7 @@ class GrimoirePage:
             command_to_run = self.__get_directives_str()
         else:
             command_to_run = [command]
+        url_to_run = None
         if url is None:
             url_to_run = self.__get_urls_all()
         else:
@@ -104,11 +103,9 @@ class GrimoirePage:
         for command in command_to_run:
             printable[command] = {}
             for url in url_to_run:
-                all = map_command[command]().stats(command, self.data["server"][url])
+                all = map_command[command]().stats(command, self.data['server'][url])
                 for key in all.keys():
-                    printable[command][key] = printable[command].get(key, 0) + int(
-                        all[key]
-                    )
+                    printable[command][key] = printable[command].get("key", 0) + int(all[key])
 
         for command in printable.keys():
             message = [(k, v) for k, v in printable[command].items()]
@@ -116,46 +113,21 @@ class GrimoirePage:
             print(tabulate(message, head, tablefmt="pipe"))
             print()
 
-    def info(self, command=None, url=None) -> None:
-        """
-        Launch info command for plugin
-        """
-        map_command = self.__get_directives_and_class()
-        if command is None:
-            command_to_run = self.__get_directives_str()
-        else:
-            command_to_run = [command]
-        if url is None:
-            url_to_run = self.__get_urls_all()
-        else:
-            url_to_run = [url]
-
-        printable = {}
-        for command in command_to_run:
-            printable[command] = {}
-            for url in url_to_run:
-                all = map_command[command]().info(directive=command, data=self.data["server"][url])
-                printable[command][url]=all
-
-        pprint(printable)
-
-
     def add(self, url) -> bool:
         """
         Add command for url
         """
-        for e in url:
-            if self.data.get("server") is None:
-                self.data["server"] = {}
-            if self.data["server"].get(e) is None:
-                self.data["server"][e] = {"url": e}
-        with open(self.setting_manager.data_path, "w") as json_file:
+        if self.data.get("server") is None:
+            self.data["server"]={}
+        if self.data['server'].get(url) is None :
+            self.data['server'][url] = {"url": url}
+        with open(self.setting_manager.data_path, 'w') as json_file:
             json.dump(self.data, json_file)
 
     def remove(self, url=None) -> bool:
         """
         Remove command for url
         """
-        self.data["server"].pop(url, None)
-        with open(self.setting_manager.data_path, "w") as json_file:
+        self.data['server'].pop(url, None)
+        with open(self.setting_manager.data_path, 'w') as json_file:
             json.dump(self.data, json_file)
