@@ -28,9 +28,9 @@ class Plugin(object):
         """
         raise NotImplementedError
 
-    def info(self, directive: str, data: dict) :
+    @staticmethod
+    def get_directives() -> [str]:
         """
-        Return info of the directive
+        Return all the directive
         """
-        return data.get(directive,dict())
-
+        raise NotImplementedError
\ No newline at end of file
