@@ -1,6 +1,7 @@
 from tabulate import tabulate
 
-class ColorClass:
+
+class PrintColor:
     def __init__(self, palet=None):
         if palet is None:
             palet = dict()
@@ -10,19 +11,6 @@ class ColorClass:
         self.fail_color = palet.get("fail", "\033[91m")
         self.end_color = palet.get("endc", "\033[0m")
 
-    def info(self, message: str) -> str:
-        raise NotImplementedError
-
-    def debug(self, message: str) -> str:
-        raise NotImplementedError
-
-    def warning(self, message: str) -> str:
-        raise NotImplementedError
-
-    def fail(self, message: str) -> str:
-        raise NotImplementedError
-
-class StrColor(ColorClass):
     def __printer__(self, message: str, color: str = None) -> str:
         return f"{color}{message}{self.end_color}"
 
@@ -39,19 +27,8 @@ class StrColor(ColorClass):
         return self.__printer__(message, self.fail_color)
 
 
-class PrintColor(ColorClass):
-    def __init__(self, palet=None):
-        super().__init__(palet)
-        self.s = StrColor(palet)
-
-    def info(self, message: str) -> str:
-        return self.s.info(message)
-
-    def debug(self, message: str) -> str:
-        return self.s.debug(message)
-
-    def warning(self, message: str) -> str:
-        return self.s.warning(message)
-
-    def fail(self, message: str) -> str:
-        return self.s.fail(message)
+def print_t(input, headers: [str] = None):
+    if headers:
+        print(tabulate(input, headers, tablefmt="pipe"))
+    else:
+        print(tabulate(input, tablefmt="pipe"))
